#include <string>
#include <iostream>

int main()
{
	std::string s = "abc";

	std::cout << s << std::endl;
}
